@@ -82,7 +82,6 @@ class H2ODeepLearning(H2ODeepLearningParams, H2OSupervisedAlgorithmWithFoldColum
                  quietMode=False,
                  scoreValidationSampling="Uniform",
                  overwriteWithBestModel=True,
-                 autoencoder=False,
                  useAllFactorLevels=True,
                  standardize=True,
                  diagnostics=True,
@@ -138,6 +137,9 @@ class H2ODeepLearning(H2ODeepLearningParams, H2OSupervisedAlgorithmWithFoldColum
                 kwargs['calculateFeatureImportances'] = kwargs['variableImportances']
             del kwargs['variableImportances']
             warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.36.")
+        if 'autoencoder' in kwargs:
+            del kwargs['autoencoder']
+            warn("The parameter 'autoencoder' is deprecated and will be removed in the version 3.36.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
