@@ -19,14 +19,13 @@ from warnings import warn
 from pyspark import keyword_only
 from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithm import H2OSupervisedAlgorithm
+from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.models.H2OGLMMOJOModel import H2OGLMMOJOModel
 from ai.h2o.sparkling.ml.params.H2OGLMParams import H2OGLMParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.FamilyBasedH2OTrainFramePreparation import FamilyBasedH2OTrainFramePreparation
 
 
-class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH2OTrainFramePreparation):
+class H2OGLM(H2OGLMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
@@ -36,6 +35,7 @@ class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  betaConstraints=None,
                  interactionPairs=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -86,6 +86,7 @@ class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  maxConfusionMatrixSize=20,
                  computePValues=False,
                  removeCollinearCols=False,
+                 generateScoringHistory=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -105,16 +106,14 @@ class H2OGLM(H2OGLMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
                  exportCheckpointsDir=None,
-                 aucType="AUTO",
-                 **kwargs):
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGLM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGLM", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        if 'distribution' in kwargs:
-            del kwargs['distribution']
-            warn("The parameter 'distribution' is deprecated and will be removed in the version 3.34.")
+        kwargs = self._updateInitKwargs(kwargs)
+
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
