@@ -22,11 +22,10 @@ from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OTreeBasedSupervisedAlgorithm import H2OTreeBasedSupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OXGBoostMOJOModel import H2OXGBoostMOJOModel
 from ai.h2o.sparkling.ml.params.H2OXGBoostParams import H2OXGBoostParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.DistributionBasedH2OTrainFramePreparation import DistributionBasedH2OTrainFramePreparation
 
 
-class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
+class H2OXGBoost(H2OXGBoostParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
@@ -34,6 +33,7 @@ class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgori
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -84,8 +84,9 @@ class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgori
                  skipDrop=0.0,
                  dmatrixType="auto",
                  backend="auto",
-                 gpuId=0,
+                 gpuId=None,
                  interactionConstraints=None,
+                 scalePosWeight=1.0,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -113,6 +114,7 @@ class H2OXGBoost(H2OXGBoostParams, H2OCommonParams, H2OTreeBasedSupervisedAlgori
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OXGBoost", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
