@@ -30,6 +30,7 @@ class H2ODeepLearningClassifier(H2ODeepLearning):
                  initialWeights=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -78,11 +79,10 @@ class H2ODeepLearningClassifier(H2ODeepLearning):
                  quietMode=False,
                  scoreValidationSampling="Uniform",
                  overwriteWithBestModel=True,
-                 autoencoder=False,
                  useAllFactorLevels=True,
                  standardize=True,
                  diagnostics=True,
-                 variableImportances=True,
+                 calculateFeatureImportances=True,
                  fastMode=True,
                  forceLoadBalance=True,
                  replicateTrainingData=True,
@@ -121,14 +121,22 @@ class H2ODeepLearningClassifier(H2ODeepLearning):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.0,
                  exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 aucType="AUTO",
+                 **kwargs):
         Initializer.load_sparkling_jar()
         super(H2ODeepLearning, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2ODeepLearningClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
         kwargs = self._updateInitKwargs(kwargs)
-
+        if 'variableImportances' in kwargs:
+            if 'calculateFeatureImportances' not in kwargs:
+                kwargs['calculateFeatureImportances'] = kwargs['variableImportances']
+            del kwargs['variableImportances']
+            warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.36.")
+        if 'autoencoder' in kwargs:
+            del kwargs['autoencoder']
+            warn("The parameter 'autoencoder' is deprecated and will be removed in the version 3.36.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
