@@ -4,7 +4,9 @@ from h2o.utils.compatibility import *  # NOQA
 
 import h2o
 from h2o.utils.typechecks import assert_is_type
+from ..exceptions import H2OValueError
 from ..frame import H2OFrame
+from .extensions import has_extension
 from .model_base import ModelBase
 
 
@@ -74,5 +76,7 @@ class H2OOrdinalModel(ModelBase):
 
         :returns: A scoring history plot.
         """
+        if not has_extension(self, 'ScoringHistory'):
+            raise H2OValueError("Scoring history plot is not available for this type of model (%s)." % self.algo)
 
-        self._plot(timestep=timestep, metric=metric, **kwargs)
+        self.scoring_history_plot(timestep=timestep, metric=metric, **kwargs)
