@@ -22,13 +22,16 @@ from pysparkling.ml.features import *
 from pysparkling.ml.models import *
 
 __all__ = ["ColumnPruner", "H2OGBM", "H2ODeepLearning", "H2OAutoML", "H2OXGBoost", "H2OGLM", "H2OCoxPH", "H2OGAM", "H2OMOJOModel",
-           "H2OSupervisedMOJOModel", "H2OTreeBasedSupervisedMOJOModel", "H2OUnsupervisedMOJOModel", "H2OCoxPHMOJOModel",
-           "H2OTreeBasedUnsupervisedMOJOModel", "H2OMOJOPipelineModel", "H2OGridSearch", "H2OMOJOSettings", "H2OKMeans",
-           "H2OTargetEncoder", "H2ODRF", "H2OAutoMLClassifier", "H2OGLMClassifier", "H2OGAMClassifier", "H2OGBMClassifier", "H2OXGBoostClassifier",
+           "H2OAlgorithmMOJOModel", "H2OFeatureMOJOModel", "H2OSupervisedMOJOModel", "H2OTreeBasedSupervisedMOJOModel",
+           "H2OUnsupervisedMOJOModel", "H2OCoxPHMOJOModel", "H2OTreeBasedUnsupervisedMOJOModel", "H2OMOJOPipelineModel",
+           "H2OGridSearch", "H2OMOJOSettings", "H2OKMeans", "H2OTargetEncoder", "H2ODRF", "H2OAutoMLClassifier",
+           "H2OGLMClassifier", "H2OGAMClassifier", "H2OGBMClassifier", "H2OXGBoostClassifier",
            "H2ODeepLearningClassifier", "H2ODRFClassifier", "H2OAutoMLRegressor", "H2OGLMRegressor", "H2OGBMRegressor",
            "H2OGAMRegressor", "H2OXGBoostRegressor", "H2ODeepLearningRegressor", "H2ODRFRegressor", "H2OBinaryModel",
            "H2OIsolationForest", "H2OKMeansMOJOModel", "H2OGLMMOJOModel", "H2OGAMMOJOModel", "H2OGBMMOJOModel", "H2OXGBoostMOJOModel",
-           "H2ODeepLearningMOJOModel", "H2ODRFMOJOModel", "H2OIsolationForestMOJOModel", "H2OWord2Vec"]
+           "H2ODeepLearningMOJOModel", "H2ODRFMOJOModel", "H2OIsolationForestMOJOModel", "H2OWord2Vec", "H2OAutoEncoder",
+           "H2OAutoEncoderMOJOModel", "H2OPCA", "H2OPCAMOJOModel", "H2OGLRM", "H2OGLRMMOJOModel", "H2ORuleFit",
+           "H2ORuleFitClassifier", "H2ORuleFitRegressor", "H2ORuleFitMOJOModel"]
 
 from pysparkling.initializer import Initializer
 
